interactive_timeline library

Classes

EventMarkerInfo
Positional data for event markers supplied to the builder/painter.
TickDrawContext
Context/config provided to the custom tick painter for convenience.
TickInfo
Information about an individual tick passed to the custom tick painter.
TimelineEvent
TimelineWidget

Enums

EventLabelAlign
Alignment for a ranged event's label when sticky behavior is enabled.
TimeScaleLOD

Typedefs

EventMarkerShapePainter = void Function(Canvas canvas, TimelineEvent event, EventMarkerInfo info)
EventMarkerWidgetBuilder = Widget Function(BuildContext context, TimelineEvent event, EventMarkerInfo info)
TickShapePainter = void Function(Canvas canvas, TickInfo tick, TickDrawContext ctx)
TimelineEventTap = void Function(TimelineEvent event)